Skip to main contentModule event_handler
Source - EventHandlerConfig
- Configuration for the shared event handler.
Both GUI and CLI provide their own config with the session store + current session state.
- EventHandlerResult
- Result from processing an event. Contains any state updates the caller should apply.
- SessionPersistence
- Trait for session persistence, so the event handler doesn’t depend on rho-session directly.
- handle_event
- Process an agent event, performing any side effects (persistence, etc).
Returns state updates the caller should apply, or None if no action needed.